test/jtreg-ext/requires/VMProps.java
changeset 48957 af49718d8cf2
parent 48880 ee49ac008730
child 49008 d777541fceba
--- a/test/jtreg-ext/requires/VMProps.java	Mon Feb 12 15:29:35 2018 +0100
+++ b/test/jtreg-ext/requires/VMProps.java	Fri Feb 09 10:18:19 2018 +0100
@@ -352,9 +352,9 @@
      * @return true if docker is supported in a given environment
      */
     protected String dockerSupport() {
         // currently docker testing is only supported for Linux-x64 and Linux-ppc64le
         String arch = System.getProperty("os.arch");
-        if (! (Platform.isLinux() && (Platform.isX64() || arch.equals("ppc64le")))) {
+        if (! (Platform.isLinux() && (Platform.isX64() || Platform.isS390x() || arch.equals("ppc64le")))) {
             return "false";
         }
@@ -352,9 +352,9 @@
      */
     protected String dockerSupport() {
-        // currently docker testing is only supported for Linux-x64 and Linux-ppc64le
+        // currently docker testing is only supported for Linux-x64, Linux-s390x and Linux-ppc64le
         String arch = System.getProperty("os.arch");